@@ -2,7 +2,13 @@
 from typing import Dict, List, Sequence
 from warnings import warn
 
-from .spy_calls import BaseSpyCall, SpyCall, VerifyRehearsal, WhenRehearsal, match_call
+from .spy_events import (
+    AnySpyEvent,
+    SpyEvent,
+    VerifyRehearsal,
+    WhenRehearsal,
+    match_event,
+)
 from .warnings import MiscalledStubWarning, RedundantVerifyWarning
 
 
@@ -10,15 +16,15 @@ class WarningChecker:
     """An interface to inspect the call list and trigger any necessary warnings."""
 
     @staticmethod
-    def check(all_calls: Sequence[BaseSpyCall]) -> None:
+    def check(all_calls: Sequence[AnySpyEvent]) -> None:
         """Check full call and rehearsal list for any potential misuse."""
         _check_no_miscalled_stubs(all_calls)
         _check_no_redundant_verify(all_calls)
 
 
-def _check_no_miscalled_stubs(all_calls: Sequence[BaseSpyCall]) -> None:
+def _check_no_miscalled_stubs(all_calls: Sequence[AnySpyEvent]) -> None:
     """Ensure every call matches a rehearsal, if the spy has rehearsals."""
-    all_calls_by_id: Dict[int, List[BaseSpyCall]] = {}
+    all_calls_by_id: Dict[int, List[AnySpyEvent]] = {}
 
     for call in all_calls:
         spy_id = call.spy_id
@@ -26,23 +32,23 @@ def _check_no_miscalled_stubs(all_calls: Sequence[BaseSpyCall]) -> None:
         all_calls_by_id[spy_id] = spy_calls + [call]
 
     for spy_calls in all_calls_by_id.values():
-        unmatched: List[SpyCall] = []
+        unmatched: List[SpyEvent] = []
 
         for index, call in enumerate(spy_calls):
             past_stubs = [
                 wr for wr in spy_calls[0:index] if isinstance(wr, WhenRehearsal)
             ]
 
-            matched_past_stubs = [wr for wr in past_stubs if match_call(call, wr)]
+            matched_past_stubs = [wr for wr in past_stubs if match_event(call, wr)]
 
             matched_future_verifies = [
                 vr
                 for vr in spy_calls[index + 1 :]
-                if isinstance(vr, VerifyRehearsal) and match_call(call, vr)
+                if isinstance(vr, VerifyRehearsal) and match_event(call, vr)
             ]
 
             if (
-                isinstance(call, SpyCall)
+                isinstance(call, SpyEvent)
                 and len(past_stubs) > 0
                 and len(matched_past_stubs) == 0
                 and len(matched_future_verifies) == 0
@@ -55,7 +61,7 @@ def _check_no_miscalled_stubs(all_calls: Sequence[BaseSpyCall]) -> None:
                 unmatched = []
 
 
-def _check_no_redundant_verify(all_calls: Sequence[BaseSpyCall]) -> None:
+def _check_no_redundant_verify(all_calls: Sequence[AnySpyEvent]) -> None:
     when_rehearsals = [c for c in all_calls if isinstance(c, WhenRehearsal)]
     verify_rehearsals = [c for c in all_calls if isinstance(c, VerifyRehearsal)]
 
